
Introduction
============

`do_x3dna <http://do-x3dna.readthedocs.io>`_ generates large amount of data and analyzing these data is difficult.
Therefore, ``dnaMD`` is developed to analyze data obtained from `do_x3dna <http://do-x3dna.readthedocs.io>`_. It contains
set of tools to analyze the data.


``dnaMD`` is written in Python and it is also available as Python module.
It can be used in Python scripting for fast and flexible analysis of
`do_x3dna <http://do-x3dna.readthedocs.io>`_
data.

**For detailed documentation about the dnaMD, please visit**  `do_x3dna <http://do-x3dna.readthedocs.io>`_.
